@@ -126,7 +126,7 @@ log_generic () {
   case $logging in
     init) ;;  # Just echo the message, don't save it anywhere
     file)
-      if [ "$helper_exist" -eq "0" ]; then
+      if [ -n "$helper" ]; then
         echo "$msg" | "$helper" "$user" log "$err_log"
       fi
     ;;
@@ -150,7 +150,7 @@ eval_log_error () {
   local cmd="$1"
   case $logging in
     file)
-     if [ "$helper_exist" -eq "0" ]; then
+     if [ -n "$helper" ]; then
         cmd="$cmd 2>&1 | "`shell_quote_string "$helper"`" $user log "`shell_quote_string "$err_log"`
      fi
      ;;
@@ -273,7 +273,16 @@ wsrep_recover_position() {
     wsrep_start_position_opt="--wsrep_start_position=$start_pos"
   fi
 
-  [ $ret -eq 0 ] && rm $wr_logfile
+  if [ $ret -eq 0 ] ; then
+    local wr_logfile_permanent="$DATADIR/wsrep_recovery.ok"
+  else
+    local wr_logfile_permanent="$DATADIR/wsrep_recovery.fail"
+  fi
+  touch $wr_logfile_permanent
+  [ "$euid" = "0" ] && chown $user $wr_logfile_permanent
+  chmod 600 $wr_logfile_permanent
+  cat "$wr_logfile" >> $wr_logfile_permanent
+  rm -f "$wr_logfile"
 
   return $ret
 }
@@ -440,8 +449,7 @@ mysqld_ld_preload_text() {
 set_malloc_lib() {
   malloc_lib="$1"
   if expr "$malloc_lib" : "\(tcmalloc\|jemalloc\)" > /dev/null ; then
-    export PATH=$PATH:/sbin
-    if ! command -v ldconfig > /dev/null 2>&1
+    if ! my_which ldconfig > /dev/null 2>&1
     then
       log_error "ldconfig command not found, required for ldconfig -p"
       exit 1
@@ -524,9 +532,10 @@ fi
 
 helper=`find_in_bin mysqld_safe_helper`
 print_defaults=`find_in_bin my_print_defaults`
+
 # Check if helper exists
-command -v $helper --help >/dev/null 2>&1
-helper_exist=$?
+$helper --help >/dev/null 2>&1 || helper=""
+
 #
 # Second, try to find the data directory
 #
@@ -562,8 +571,8 @@ append_arg_to_args () {
 
 args=
 
-# Get first arguments from the my.cnf file, groups [mysqld] and [mysqld_safe]
-# and then merge with the command line arguments
+# Get first arguments from the my.cnf file, groups [mysqld] and [server]
+# (and related) and then merge with the command line arguments
 
 SET_USER=2
 parse_arguments `$print_defaults $defaults --loose-verbose --mysqld`
@@ -575,7 +584,7 @@ fi
 # If arguments come from [mysqld_safe] section of my.cnf
 # we complain about unrecognized options
 unrecognized_handling=complain
-parse_arguments `$print_defaults $defaults --loose-verbose mysqld_safe safe_mysqld mariadb_safe`
+parse_arguments `$print_defaults $defaults --loose-verbose mysqld_safe safe_mysqld mariadb_safe mariadbd-safe`
 
 # We only need to pass arguments through to the server if we don't
 # handle them here.  So, we collect unrecognized options (passed on
@@ -933,6 +942,7 @@ fi
 
 # Avoid 'nohup: ignoring input' warning
 test -n "$NOHUP_NICENESS" && cmd="$cmd < /dev/null"
+
 log_notice "Starting $MYSQLD daemon with databases from $DATADIR"
 
 # variable to track the current number of "fast" (a.k.a. subsecond) restarts
