@@ -44,7 +44,7 @@
 /*                                                                     */
 /***********************************************************************/
 #include "my_global.h"
-#if defined(_WIN32)
+#if defined(__WIN__)
 //#include <windows.h>
 #else
 #if defined(UNIX) || defined(UNIV_LINUX)
@@ -81,9 +81,9 @@
 #include "rcmsg.h"
 #endif   // NEWMSG
 
-#if defined(_WIN32)
+#if defined(__WIN__)
 extern HINSTANCE s_hModule;                   /* Saved module handle    */
-#endif   // _WIN32
+#endif   // __WIN__
 
 #if defined(XMSG)
 extern char *msg_path;
@@ -96,7 +96,7 @@ char *msglang(void);
 typedef struct {
   ushort Segsize;
   ushort Size;
-} AREASIZE;
+  } AREASIZE;
 
 ACTIVITY defActivity = {            /* Describes activity and language */
   NULL,                             /* Points to user work area(s)     */
@@ -147,7 +147,7 @@ PGLOBAL PlugInit(LPCSTR Language, size_t worksize)
 	PGLOBAL g;
 
 	if (trace(2))
-		htrc("PlugInit: Language='%s'\n",
+		htrc("PlugInit: Language='%-.256s'\n",
 			((!Language) ? "Null" : (char*)Language));
 
 	try {
@@ -184,7 +184,7 @@ PGLOBAL PlugInit(LPCSTR Language, size_t worksize)
 /***********************************************************************/
 /*  PlugExit: Terminate Plug operations.                               */
 /***********************************************************************/
-PGLOBAL PlugExit(PGLOBAL g)
+int PlugExit(PGLOBAL g)
 {
 	if (g) {
 		PDBUSER dup = PlgGetUser(g);
@@ -196,7 +196,7 @@ PGLOBAL PlugExit(PGLOBAL g)
 		delete g;
 	}	// endif g
 
-  return NULL;
+  return 0;
 } // end of PlugExit
 
 /***********************************************************************/
@@ -204,8 +204,8 @@ PGLOBAL PlugExit(PGLOBAL g)
 /*  Note: this routine is not really implemented for Unix.             */
 /***********************************************************************/
 LPSTR PlugRemoveType(LPSTR pBuff, LPCSTR FileName)
-{
-#if defined(_WIN32)
+  {
+#if defined(__WIN__)
   char drive[_MAX_DRIVE];
 #else
   char *drive = NULL;
@@ -217,22 +217,23 @@ LPSTR PlugRemoveType(LPSTR pBuff, LPCSTR FileName)
   _splitpath(FileName, drive, direc, fname, ftype);
 
   if (trace(2)) {
-    htrc("after _splitpath: FileName=%s\n", FileName);
-    htrc("drive=%s dir=%s fname=%s ext=%s\n",
+    htrc("after _splitpath: FileName=%-.256s\n", FileName);
+    htrc("drive=%-.256s dir=%-.256s fname=%-.256s ext=%-.256s\n",
           SVP(drive), direc, fname, ftype);
     } // endif trace
 
   _makepath(pBuff, drive, direc, fname, "");
 
   if (trace(2))
-    htrc("buff='%s'\n", pBuff);
+    htrc("buff='%-.256s'\n", pBuff);
 
   return pBuff;
-} // end of PlugRemoveType
+  } // end of PlugRemoveType
+
 
 BOOL PlugIsAbsolutePath(LPCSTR path)
 {
-#if defined(_WIN32)
+#if defined(__WIN__)
   return ((path[0] >= 'a' && path[0] <= 'z') ||
           (path[0] >= 'A' && path[0] <= 'Z')) && path[1] == ':';
 #else
@@ -245,19 +246,19 @@ BOOL PlugIsAbsolutePath(LPCSTR path)
 /*  Note: this routine is not really implemented for Unix.             */
 /***********************************************************************/
 LPCSTR PlugSetPath(LPSTR pBuff, LPCSTR prefix, LPCSTR FileName, LPCSTR defpath)
-{
+  {
   char newname[_MAX_PATH];
   char direc[_MAX_DIR], defdir[_MAX_DIR], tmpdir[_MAX_DIR];
   char fname[_MAX_FNAME];
   char ftype[_MAX_EXT];
-#if defined(_WIN32)
+#if defined(__WIN__)
   char drive[_MAX_DRIVE], defdrv[_MAX_DRIVE];
 #else
   char *drive = NULL, *defdrv = NULL;
 #endif
 
 	if (trace(2))
-		htrc("prefix=%s fn=%s path=%s\n", prefix, FileName, defpath);
+		htrc("prefix=%-.256s fn=%-.256s path=%-.256s\n", prefix, FileName, defpath);
 
   if (!strncmp(FileName, "//", 2) || !strncmp(FileName, "\\\\", 2)) {
     strcpy(pBuff, FileName);       // Remote file
@@ -270,18 +271,18 @@ LPCSTR PlugSetPath(LPSTR pBuff, LPCSTR prefix, LPCSTR FileName, LPCSTR defpath)
     return pBuff;
   } // endif
   
-#if !defined(_WIN32)
+#if !defined(__WIN__)
   if (*FileName == '~') {
     if (_fullpath(pBuff, FileName, _MAX_PATH)) {
       if (trace(2))
-        htrc("pbuff='%s'\n", pBuff);
+        htrc("pbuff='%-.256s'\n", pBuff);
 
      return pBuff;
     } else
       return FileName;     // Error, return unchanged name
       
     } // endif FileName  
-#endif   // !_WIN32
+#endif   // !__WIN__
   
   if (prefix && strcmp(prefix, ".") && !PlugIsAbsolutePath(defpath))
   {
@@ -309,12 +310,12 @@ LPCSTR PlugSetPath(LPSTR pBuff, LPCSTR prefix, LPCSTR FileName, LPCSTR defpath)
   _splitpath(tmpdir, defdrv, defdir, NULL, NULL);
 
   if (trace(2)) {
-    htrc("after _splitpath: FileName=%s\n", FileName);
-#if defined(_WIN32)
-    htrc("drive=%s dir=%s fname=%s ext=%s\n", drive, direc, fname, ftype);
-    htrc("defdrv=%s defdir=%s\n", defdrv, defdir);
+    htrc("after _splitpath: FileName=%-.256s\n", FileName);
+#if defined(__WIN__)
+    htrc("drive=%-.256s dir=%-.256s fname=%-.256s ext=%-.256s\n", drive, direc, fname, ftype);
+    htrc("defdrv=%-.256s defdir=%-.256s\n", defdrv, defdir);
 #else
-    htrc("dir=%s fname=%s ext=%s\n", direc, fname, ftype);
+    htrc("dir=%-.256s fname=%-.256s ext=%-.256s\n", direc, fname, ftype);
 #endif
     } // endif trace
 
@@ -336,24 +337,24 @@ LPCSTR PlugSetPath(LPSTR pBuff, LPCSTR prefix, LPCSTR FileName, LPCSTR defpath)
   _makepath(newname, drive, direc, fname, ftype);
 
   if (trace(2))
-    htrc("newname='%s'\n", newname);
+    htrc("newname='%-.256s'\n", newname);
 
   if (_fullpath(pBuff, newname, _MAX_PATH)) {
     if (trace(2))
-      htrc("pbuff='%s'\n", pBuff);
+      htrc("pbuff='%-.256s'\n", pBuff);
 
     return pBuff;
   } else
     return FileName;     // Error, return unchanged name
 
-} // end of PlugSetPath
+  } // end of PlugSetPath
 
 #if defined(XMSG)
 /***********************************************************************/
 /*  PlugGetMessage: get a message from the message file.               */
 /***********************************************************************/
 char *PlugReadMessage(PGLOBAL g, int mid, char *m)
-{
+  {
   char  msgfile[_MAX_PATH], msgid[32], buff[256];
   char *msg;
   FILE *mfile = NULL;
@@ -365,22 +366,22 @@ char *PlugReadMessage(PGLOBAL g, int mid, char *m)
   PlugSetPath(msgfile, NULL, buff, msg_path);
 
   if (!(mfile = fopen(msgfile, "rt"))) {
-    sprintf(stmsg, "Fail to open message file %s", msgfile);
+    sprintf(stmsg, "Fail to open message file %-.256s", msgfile);
     goto err;
     } // endif mfile
 
   for (;;)
     if (!fgets(buff, 256, mfile)) {
-      sprintf(stmsg, "Cannot get message %d %s", mid, SVP(m));
+      sprintf(stmsg, "Cannot get message %d %-.256s", mid, SVP(m));
       goto fin;
     } else
       if (atoi(buff) == mid)
         break;
 
-  if (sscanf(buff, " %*d %.31s \"%.255[^\"]", msgid, stmsg) < 2) {
+  if (sscanf(buff, " %*d %-.256s \"%[^\"]", msgid, stmsg) < 2) {
     // Old message file
-    if (!sscanf(buff, " %*d \"%.255[^\"]", stmsg)) {
-      sprintf(stmsg, "Bad message file for %d %s", mid, SVP(m));
+    if (!sscanf(buff, " %*d \"%[^\"]", stmsg)) {
+      sprintf(stmsg, "Bad message file for %d %-.256s", mid, SVP(m));
       goto fin;
     } else
       m = NULL;
@@ -404,14 +405,14 @@ char *PlugReadMessage(PGLOBAL g, int mid, char *m)
     msg =  stmsg;
 
   return msg;
-} // end of PlugReadMessage
+  } // end of PlugReadMessage
 
 #elif defined(NEWMSG)
 /***********************************************************************/
 /*  PlugGetMessage: get a message from the resource string table.      */
 /***********************************************************************/
 char *PlugGetMessage(PGLOBAL g, int mid)
-{
+  {
   char *msg;
 
 #if 0 // was !defined(UNIX) && !defined(UNIV_LINUX)
@@ -439,22 +440,22 @@ char *PlugGetMessage(PGLOBAL g, int mid)
     msg =  stmsg;
 
   return msg;
-} // end of PlugGetMessage
+  } // end of PlugGetMessage
 #endif     // NEWMSG
 
-#if defined(_WIN32)
+#if defined(__WIN__)
 /***********************************************************************/
 /*  Return the line length of the console screen buffer.               */
 /***********************************************************************/
 short GetLineLength(PGLOBAL g)
-{
+  {
   CONSOLE_SCREEN_BUFFER_INFO coninfo;
   HANDLE  hcons = GetStdHandle(STD_OUTPUT_HANDLE);
   BOOL    b = GetConsoleScreenBufferInfo(hcons, &coninfo);
 
   return (b) ? coninfo.dwSize.X : 0;
-} // end of GetLineLength
-#endif   // _WIN32
+  } // end of GetLineLength
+#endif   // __WIN__
 
 /***********************************************************************/
 /*  Program for memory allocation of work and language areas.          */
@@ -464,7 +465,7 @@ bool AllocSarea(PGLOBAL g, size_t size)
   /*********************************************************************/
   /*  This is the allocation routine for the WIN32/UNIX/AIX version.   */
   /*********************************************************************/
-#if defined(_WIN32)
+#if defined(__WIN__)
 	if (size >= 1048576)			 // 1M
 		g->Sarea = VirtualAlloc(NULL, size, MEM_COMMIT | MEM_RESERVE, PAGE_READWRITE);
 	else
@@ -474,20 +475,18 @@ bool AllocSarea(PGLOBAL g, size_t size)
 	if (!g->Sarea) {
 		sprintf(g->Message, MSG(MALLOC_ERROR), "malloc");
 		g->Sarea_Size = 0;
-	}	else {
-    g->Sarea_Size = size;
-    PlugSubSet(g->Sarea, size);
-  } // endif Sarea
+	}	else
+		g->Sarea_Size = size;
 
 #if defined(DEVELOPMENT)
 	if (true) {
 #else
 	if (trace(8)) {
 #endif
-    if (g->Sarea) {
+    if (g->Sarea)
       htrc("Work area of %zd allocated at %p\n", size, g->Sarea);
-    } else
-      htrc("SareaAlloc: %s\n", g->Message);
+    else
+      htrc("SareaAlloc: %-.256s\n", g->Message);
 
   } // endif trace
 
@@ -500,7 +499,7 @@ bool AllocSarea(PGLOBAL g, size_t size)
 void FreeSarea(PGLOBAL g)
 {
 	if (g->Sarea) {
-#if defined(_WIN32)
+#if defined(__WIN__)
 		if (g->Sarea_Size >= 1048576)			 // 1M
 			VirtualFree(g->Sarea, 0, MEM_RELEASE);
 		else
@@ -527,13 +526,13 @@ void FreeSarea(PGLOBAL g)
 /*  the address and size not larger than memory size.                  */
 /***********************************************************************/
 BOOL PlugSubSet(void *memp, size_t size)
-{
+  {
   PPOOLHEADER pph = (PPOOLHEADER)memp;
 
   pph->To_Free = (size_t)sizeof(POOLHEADER);
   pph->FreeBlk = size - pph->To_Free;
   return FALSE;
-} /* end of PlugSubSet */
+  } /* end of PlugSubSet */
 
 /***********************************************************************/
 /*  Use it to export a function that do throwing.                      */
@@ -569,11 +568,11 @@ void *PlugSubAlloc(PGLOBAL g, void *memp, size_t size)
     PCSZ pname = "Work";
 
     sprintf(g->Message,
-      "Not enough memory in %s area for request of %zd (used=%zd free=%zd)",
+      "Not enough memory in %-.256s area for request of %zu (used=%zu free=%zu)",
                           pname, size, pph->To_Free, pph->FreeBlk);
 
     if (trace(1))
-      htrc("PlugSubAlloc: %s\n", g->Message);
+      htrc("PlugSubAlloc: %-.256s\n", g->Message);
 
     DoThrow(1234);
   } /* endif size OS32 code */
@@ -596,7 +595,7 @@ void *PlugSubAlloc(PGLOBAL g, void *memp, size_t size)
 /*  Program for sub-allocating and copying a string in a storage area. */
 /***********************************************************************/
 char *PlugDup(PGLOBAL g, const char *str)
-{
+  {
   if (str) {
     char *sm = (char*)PlugSubAlloc(g, NULL, strlen(str) + 1);
 
@@ -605,33 +604,6 @@ char *PlugDup(PGLOBAL g, const char *str)
   } else
     return NULL;
 
-} // end of PlugDup 
+  } // end of PlugDup 
 
-/*************************************************************************/
-/* This routine makes a pointer from an offset to a memory pointer.      */
-/*************************************************************************/
-void* MakePtr(void* memp, size_t offset)
-{
-  // return ((offset == 0) ? NULL : &((char*)memp)[offset]);
-  return (!offset) ? NULL : (char *)memp + offset;
-} /* end of MakePtr */
-
-/*************************************************************************/
-/* This routine makes an offset from a pointer new format.               */
-/*************************************************************************/
-size_t MakeOff(void* memp, void* ptr)
-{
-  if (ptr) {
-#if defined(_DEBUG) || defined(DEVELOPMENT)
-    if (ptr <= memp) {
-      fprintf(stderr, "ptr %p <= memp %p", ptr, memp);
-      DoThrow(999);
-    } // endif ptr
-#endif   // _DEBUG  ||         DEVELOPMENT
-    return (size_t)(((char*)ptr) - ((char*)memp));
-  } else
-    return 0;
-
-} /* end of MakeOff */
-
-/*---------------------- End of PLUGUTIL program ------------------------*/
+/*--------------------- End of PLUGUTIL program -----------------------*/
